import { CSSProperties, ReactNode } from 'react';
import type { Margins } from '../types';
import type { AnnotationArrowProps } from './Annotations/Arrow';
import type { AnnotationCircleProps } from './Annotations/Circle';
import type { AnnotationEllipseProps } from './Annotations/Ellipse';
import type { AnnotationGroupProps } from './Annotations/Group';
import type { AnnotationLineProps } from './Annotations/Line';
import type { AnnotationRectangleProps } from './Annotations/Rectangle';
import type { AnnotationShapeProps } from './Annotations/Shape';
import type { AnnotationTextProps } from './Annotations/Text';
import { AxisProps } from './Axis/Axis';
import { ParallelAxisProps } from './Axis/ParallelAxis';
import { LegendProps } from './Legend';
import { PlotProps } from './Plot';
import { LineSeriesProps } from './Series/LineSeries';
import { ScatterSeriesProps } from './Series/ScatterSeries';
export declare type PlotObjectAnnotations = ({
    type: 'arrow';
} & AnnotationArrowProps) | ({
    type: 'circle';
} & AnnotationCircleProps) | ({
    type: 'ellipse';
} & AnnotationEllipseProps) | ({
    type: 'line';
} & AnnotationLineProps) | ({
    type: 'rectangle';
} & AnnotationRectangleProps) | ({
    type: 'shape';
} & AnnotationShapeProps) | ({
    type: 'text';
    children: string;
} & Omit<AnnotationTextProps, 'children'>) | ({
    type: 'group';
    children: PlotObjectAnnotations[];
} & Omit<AnnotationGroupProps, 'children'>);
declare type PlotObjectContent = {
    type: 'annotation';
    children: PlotObjectAnnotations[];
} | ({
    type: 'line';
} & LineSeriesProps) | ({
    type: 'scatter';
} & ScatterSeriesProps);
export interface PlotObjectPlot {
    axes: Array<({
        type: 'main';
    } & AxisProps) | ({
        type: 'secondary';
    } & ParallelAxisProps)>;
    content: PlotObjectContent[];
    legend?: LegendProps;
    dimensions: {
        width: number;
        height: number;
        margin?: Partial<Margins>;
    };
    svg?: Pick<PlotProps, 'plotViewportStyle' | 'seriesViewportStyle'> & {
        className?: string;
        id?: string;
        style?: PlotProps['svgStyle'];
    };
    colorScheme?: Iterable<string>;
    seriesViewportStyle?: CSSProperties;
}
export interface PlotObjectProps {
    plot: PlotObjectPlot;
    children?: ReactNode;
}
export declare function PlotObject({ plot: { dimensions, svg, seriesViewportStyle, axes, content, legend, colorScheme, }, children, }: PlotObjectProps): JSX.Element;
export {};
