"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BarSeries = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const legendContext_1 = require("../../contexts/legendContext");
const plotContext_1 = require("../../contexts/plotContext");
const hooks_1 = require("../../hooks");
const utils_1 = require("../../utils");
const ScatterSeries_1 = require("./ScatterSeries");
function BarSeries(props) {
    var _a, _b;
    const [, legendDispatch] = (0, legendContext_1.useLegend)();
    const { colorScaler } = (0, plotContext_1.usePlotContext)();
    const id = (0, utils_1.useId)(props.id, 'series');
    const { lineStyle = {}, displayMarkers = false, hidden, ...otherProps } = props;
    const { xAxis = 'x', yAxis = 'y', xShift: oldXShift = '0', yShift: oldYShift = '0', pointLabel, displayErrorBars, } = otherProps;
    const { xShift, yShift } = (0, hooks_1.useShift)({
        xAxis,
        yAxis,
        xShift: oldXShift,
        yShift: oldYShift,
    });
    const lineProps = {
        id,
        data: props.data,
        xAxis,
        yAxis,
        lineStyle: (0, utils_1.functionalStyle)({}, lineStyle, { id }),
        transform: `translate(${xShift},${yShift})`,
    };
    const colorLine = (lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke)
        ? lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke.toString()
        : colorScaler(id);
    const color = ((_b = (_a = otherProps.markerStyle) === null || _a === void 0 ? void 0 : _a.fill) === null || _b === void 0 ? void 0 : _b.toString()) || colorScaler(id);
    const figure = otherProps.markerShape || 'circle';
    const shape = (0, react_1.useMemo)(() => {
        return {
            color,
            figure,
            hidden: !displayMarkers,
        };
    }, [color, displayMarkers, figure]);
    const isVisible = (0, hooks_1.useIsSeriesVisible)(id);
    (0, react_1.useEffect)(() => {
        legendDispatch({
            type: 'ADD_LEGEND_LABEL',
            payload: {
                id,
                label: otherProps.label,
                colorLine,
                shape,
            },
        });
        return () => legendDispatch({ type: 'REMOVE_LEGEND_LABEL', payload: { id } });
    }, [colorLine, legendDispatch, otherProps.label, shape, id]);
    if (hidden)
        return null;
    return ((0, jsx_runtime_1.jsxs)("g", { children: [isVisible && (0, jsx_runtime_1.jsx)(BarSeriesRender, { ...lineProps }), (0, jsx_runtime_1.jsx)(ScatterSeries_1.ScatterSeries, { ...otherProps, hidden: !displayMarkers && !pointLabel && !displayErrorBars, displayMarkers: displayMarkers, id: id })] }));
}
exports.BarSeries = BarSeries;
function BarSeriesRender({ id, data, xAxis, yAxis, lineStyle, transform, }) {
    // Get scales from context
    const { axisContext, colorScaler } = (0, plotContext_1.usePlotContext)();
    const [xScale, yScale] = (0, utils_1.validateAxis)(axisContext, xAxis, yAxis);
    const color = colorScaler(id);
    if (xScale === undefined || yScale === undefined) {
        return null;
    }
    // default style
    const style = {
        stroke: color,
        strokeWidth: 2,
        ...lineStyle,
    };
    return ((0, jsx_runtime_1.jsx)("g", { transform: transform, children: data.map(({ x, y }) => ((0, jsx_runtime_1.jsx)("line", { style: style, x1: xScale(x), x2: xScale(x), y1: yScale(y), y2: yScale(0) }, `${x}-${y}`))) }));
}
