"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createNestableContext = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
function createNestableContext(defaultValue) {
    const context = (0, react_1.createContext)(new Map());
    function useNestedContext(id) {
        const values = (0, react_1.useContext)(context);
        if (values.has(id)) {
            return values.get(id);
        }
        return defaultValue;
    }
    function NestedContextProvider(props) {
        const { id, value, children } = props;
        const parentValues = (0, react_1.useContext)(context);
        const mergedValues = (0, react_1.useMemo)(() => {
            const merged = new Map(parentValues);
            merged.set(id, value);
            return merged;
        }, [parentValues, id, value]);
        return (0, jsx_runtime_1.jsx)(context.Provider, { value: mergedValues, children: children });
    }
    return {
        useNestedContext,
        NestedContextProvider,
    };
}
exports.createNestableContext = createNestableContext;
